@@ -5,7 +5,7 @@ fn main() {
     let a = app::App::default().with_scheme(app::Scheme::Gtk);
     let mut win = window::Window::default().with_size(400, 300);
     {
-        let mut flex = Flex::default().column();
+        let mut flex = Flex::default().size_of_parent().column();
         {
             frame::Frame::default(); // filler
             let mut normal1 = button::Button::default().with_label("Normal1");
